/* GElementTest.c generated by valac 0.34.6, the Vala compiler
 * generated from GElementTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GELEMENT_TEST (gelement_test_get_type ())
#define GELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GELEMENT_TEST, GElementTest))
#define GELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GELEMENT_TEST, GElementTestClass))
#define IS_GELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GELEMENT_TEST))
#define IS_GELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GELEMENT_TEST))
#define GELEMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GELEMENT_TEST, GElementTestClass))

typedef struct _GElementTest GElementTest;
typedef struct _GElementTestClass GElementTestClass;
typedef struct _GElementTestPrivate GElementTestPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GElementTest {
	GXmlTest parent_instance;
	GElementTestPrivate * priv;
};

struct _GElementTestClass {
	GXmlTestClass parent_class;
};


static gpointer gelement_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gelement_test_get_type (void) G_GNUC_CONST;
enum  {
	GELEMENT_TEST_DUMMY_PROPERTY
};
void gelement_test_add_tests (void);
static void __lambda180_ (void);
static void ___lambda180__gtest_func (void);
static void __lambda181_ (void);
static void ___lambda181__gtest_func (void);
static void __lambda182_ (void);
static void ___lambda182__gtest_func (void);
static void __lambda183_ (void);
static void ___lambda183__gtest_func (void);
static void __lambda184_ (void);
static void ___lambda184__gtest_func (void);
static void __lambda185_ (void);
static void ___lambda185__gtest_func (void);
static void __lambda186_ (void);
static void ___lambda186__gtest_func (void);
GElementTest* gelement_test_new (void);
GElementTest* gelement_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void __lambda180_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGNode* root = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GXmlGNode* node = NULL;
		GeeBidirList* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		gpointer _tmp9_ = NULL;
		GXmlGNode* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GeeList* _tmp14_ = NULL;
		GeeList* _tmp15_ = NULL;
		GeeList* _tmp16_ = NULL;
		GeeList* _tmp17_ = NULL;
		GeeList* _tmp18_ = NULL;
		GeeList* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		GeeList* _tmp22_ = NULL;
		GeeList* _tmp23_ = NULL;
		GeeList* _tmp24_ = NULL;
		gpointer _tmp25_ = NULL;
		GXmlNamespace* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		GeeList* _tmp30_ = NULL;
		GeeList* _tmp31_ = NULL;
		GeeList* _tmp32_ = NULL;
		gpointer _tmp33_ = NULL;
		GXmlNamespace* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		GeeList* _tmp38_ = NULL;
		GeeList* _tmp39_ = NULL;
		GeeList* _tmp40_ = NULL;
		gpointer _tmp41_ = NULL;
		GXmlNamespace* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		GeeList* _tmp46_ = NULL;
		GeeList* _tmp47_ = NULL;
		GeeList* _tmp48_ = NULL;
		gpointer _tmp49_ = NULL;
		GXmlNamespace* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
#line 29 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"/></Potions>", 0, &_inner_error_);
#line 29 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		doc = _tmp0_;
#line 29 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 188 "GElementTest.c"
			goto __catch166_g_error;
		}
#line 30 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 30 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp2_ = _tmp1_;
#line 30 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GXML_TYPE_GNODE, GXmlGNode);
#line 31 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (root != NULL, "root != null");
#line 32 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp3_ = gxml_gnode_get_name (root);
#line 32 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp4_ = _tmp3_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "Potions") == 0, "root.name == \"Potions\"");
#line 32 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp5_);
#line 33 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp6_ = gxml_gnode_get_children_nodes (root);
#line 33 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp9_ = gee_list_get ((GeeList*) _tmp8_, 0);
#line 33 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp9_, GXML_TYPE_GNODE, GXmlGNode);
#line 33 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 33 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		node = _tmp10_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (node != NULL, "node != null");
#line 35 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp11_ = gxml_gnode_get_name (node);
#line 35 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp12_ = _tmp11_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = _tmp12_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "Potion") == 0, "node.name == \"Potion\"");
#line 35 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp13_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp14_ = gxml_gnode_get_namespaces (node);
#line 36 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp16_ != NULL, "node.namespaces != null");
#line 36 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp16_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp17_ = gxml_gnode_get_namespaces (node);
#line 37 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp19_ = _tmp18_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp20_ = gee_collection_get_size ((GeeCollection*) _tmp19_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp21_ == 2, "node.namespaces.size == 2");
#line 37 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp19_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp22_ = gxml_gnode_get_namespaces (node);
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp24_ = _tmp23_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp25_ = gee_list_get (_tmp24_, 0);
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp26_ = (GXmlNamespace*) _tmp25_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp27_ = gxml_namespace_get_uri (_tmp26_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "http://hogwarts.co.uk/magic") == 0, "node.namespaces[0].uri == \"http://hogwarts.co.uk/magic\"");
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp29_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp30_ = gxml_gnode_get_namespaces (node);
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp31_ = _tmp30_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp32_ = _tmp31_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp33_ = gee_list_get (_tmp32_, 0);
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp34_ = (GXmlNamespace*) _tmp33_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp35_ = gxml_namespace_get_prefix (_tmp34_);
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp36_ = _tmp35_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp37_ = _tmp36_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "magic") == 0, "node.namespaces[0].prefix == \"magic\"");
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp37_);
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 39 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp32_);
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp38_ = gxml_gnode_get_namespaces (node);
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp39_ = _tmp38_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp40_ = _tmp39_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp41_ = gee_list_get (_tmp40_, 1);
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp42_ = (GXmlNamespace*) _tmp41_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp43_ = gxml_namespace_get_prefix (_tmp42_);
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp44_ = _tmp43_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp45_ = _tmp44_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "products") == 0, "node.namespaces.get (1).prefix == \"products\"");
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp45_);
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 40 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp46_ = gxml_gnode_get_namespaces (node);
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp47_ = _tmp46_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp48_ = _tmp47_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp49_ = gee_list_get (_tmp48_, 1);
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp50_ = (GXmlNamespace*) _tmp49_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp51_ = gxml_namespace_get_uri (_tmp50_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp52_ = _tmp51_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp53_ = _tmp52_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://diagonalley.co.uk/products") == 0, "node.namespaces.get (1).uri == \"http://diagonalley.co.uk/products\"");
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp53_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp50_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp48_);
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (node);
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (root);
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (doc);
#line 361 "GElementTest.c"
	}
	goto __finally166;
	__catch166_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp54_ = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		e = _inner_error_;
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_inner_error_ = NULL;
#line 43 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp54_ = e->message;
#line 43 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp54_);
#line 44 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_assert_not_reached ();
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_error_free0 (e);
#line 380 "GElementTest.c"
	}
	__finally166:
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_clear_error (&_inner_error_);
#line 28 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		return;
#line 391 "GElementTest.c"
	}
}


static void ___lambda180__gtest_func (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	__lambda180_ ();
#line 399 "GElementTest.c"
}


static void __lambda181_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlGElement* elem = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlGDocument* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GeeBidirList* _tmp13_ = NULL;
		GeeBidirList* _tmp14_ = NULL;
		GeeBidirList* _tmp15_ = NULL;
		GeeMap* _tmp16_ = NULL;
		GeeMap* _tmp17_ = NULL;
		GeeMap* _tmp18_ = NULL;
		GeeMap* _tmp19_ = NULL;
		GeeMap* _tmp20_ = NULL;
		GeeMap* _tmp21_ = NULL;
		gint _tmp22_ = 0;
		gint _tmp23_ = 0;
		GeeMap* _tmp24_ = NULL;
		GeeMap* _tmp25_ = NULL;
		GeeMap* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gint _tmp28_ = 0;
		GXmlGDocument* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		GeeMap* _tmp34_ = NULL;
		GeeMap* _tmp35_ = NULL;
		GeeMap* _tmp36_ = NULL;
		gpointer _tmp37_ = NULL;
		GXmlNode* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		GeeMap* _tmp42_ = NULL;
		GeeMap* _tmp43_ = NULL;
		GeeMap* _tmp44_ = NULL;
		gpointer _tmp45_ = NULL;
		GXmlNode* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		GXmlGAttribute* attr = NULL;
		GXmlNode* _tmp50_ = NULL;
		GXmlGAttribute* _tmp51_ = NULL;
		GeeMap* _tmp52_ = NULL;
		GeeMap* _tmp53_ = NULL;
		GeeMap* _tmp54_ = NULL;
		gint _tmp55_ = 0;
		gint _tmp56_ = 0;
		GeeMap* _tmp57_ = NULL;
		GeeMap* _tmp58_ = NULL;
		GeeMap* _tmp59_ = NULL;
		gpointer _tmp60_ = NULL;
		GXmlNode* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		GeeMap* _tmp65_ = NULL;
		GeeMap* _tmp66_ = NULL;
		GeeMap* _tmp67_ = NULL;
		GeeMap* _tmp68_ = NULL;
		GeeMap* _tmp69_ = NULL;
		GeeMap* _tmp70_ = NULL;
		gpointer _tmp71_ = NULL;
		GXmlNode* _tmp72_ = NULL;
		GeeMap* _tmp73_ = NULL;
		GeeMap* _tmp74_ = NULL;
		GeeMap* _tmp75_ = NULL;
		gint _tmp76_ = 0;
		gint _tmp77_ = 0;
		GeeMap* _tmp78_ = NULL;
		GeeMap* _tmp79_ = NULL;
		GeeMap* _tmp80_ = NULL;
		gint _tmp81_ = 0;
		gint _tmp82_ = 0;
#line 49 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 49 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		doc = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 498 "GElementTest.c"
			goto __catch167_g_error;
		}
#line 50 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = doc;
#line 50 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) _tmp1_);
#line 50 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp3_ = _tmp2_;
#line 50 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp4_ = _tmp3_;
#line 50 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.root != null");
#line 50 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp6_ = doc;
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp7_ = gxml_document_create_element ((GXmlDocument*) _tmp6_, "alphanumeric", &_inner_error_);
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = _tmp7_;
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 523 "GElementTest.c"
			goto __catch167_g_error;
		}
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp8_ = _tmp5_;
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		elem = G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp9_ = doc;
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) _tmp9_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp11_ = _tmp10_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp12_ = _tmp11_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = gxml_node_get_children_nodes (_tmp12_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp14_ = _tmp13_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlNode*) elem);
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 53 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp16_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 53 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 53 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 53 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp18_ != NULL, "elem.attrs != null");
#line 53 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 54 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp19_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 54 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp20_ = _tmp19_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp22_ = gee_map_get_size (_tmp21_);
#line 54 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp23_ == 0, "elem.attrs.size == 0");
#line 54 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 55 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gxml_element_set_attr ((GXmlElement*) elem, "alley", "Diagon");
#line 56 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gxml_element_set_attr ((GXmlElement*) elem, "train", "Hogwarts Express");
#line 57 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp24_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 57 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp25_ = _tmp24_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp27_ = gee_map_get_size (_tmp26_);
#line 57 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp28_ == 2, "elem.attrs.size == 2");
#line 57 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = doc;
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp30_ = gxml_gnode_to_string ((GXmlGNode*) _tmp29_);
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp31_ = _tmp30_;
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp32_ = g_strconcat ("Getting attributes value alley... Node: ", _tmp31_, NULL);
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp33_ = _tmp32_;
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp33_);
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp33_);
#line 58 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp31_);
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp34_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp35_ = _tmp34_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp36_ = _tmp35_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp37_ = gee_map_get (_tmp36_, "alley");
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp38_ = (GXmlNode*) _tmp37_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp39_ = gxml_node_get_value (_tmp38_);
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp40_ = _tmp39_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp41_ = _tmp40_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "Diagon") == 0, "elem.attrs.get (\"alley\").value == \"Diagon\"");
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp41_);
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp38_);
#line 59 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp36_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp42_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp43_ = _tmp42_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp44_ = _tmp43_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp45_ = gee_map_get (_tmp44_, "train");
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp46_ = (GXmlNode*) _tmp45_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp47_ = gxml_node_get_value (_tmp46_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp48_ = _tmp47_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp49_ = _tmp48_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "Hogwarts Express") == 0, "elem.attrs.get (\"train\").value == \"Hogwarts Express\"");
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp49_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp46_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp44_);
#line 62 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gxml_element_set_attr ((GXmlElement*) elem, "owl", "");
#line 63 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp50_ = gxml_element_get_attr ((GXmlElement*) elem, "owl");
#line 63 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp51_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_GATTRIBUTE) ? ((GXmlGAttribute*) _tmp50_) : NULL;
#line 63 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (_tmp51_ == NULL) {
#line 63 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (_tmp50_);
#line 668 "GElementTest.c"
		}
#line 63 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		attr = _tmp51_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (attr != NULL, "attr != null");
#line 65 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gxml_dom_attr_set_value ((GXmlDomAttr*) attr, "Hedwig");
#line 67 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp52_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 67 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp53_ = _tmp52_;
#line 67 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp54_ = _tmp53_;
#line 67 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp55_ = gee_map_get_size (_tmp54_);
#line 67 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp56_ = _tmp55_;
#line 67 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp56_ == 3, "elem.attrs.size == 3");
#line 67 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp57_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp58_ = _tmp57_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp59_ = _tmp58_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp60_ = gee_map_get (_tmp59_, "owl");
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp61_ = (GXmlNode*) _tmp60_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp62_ = gxml_node_get_value (_tmp61_);
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp63_ = _tmp62_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp64_ = _tmp63_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "Hedwig") == 0, "elem.attrs.get (\"owl\").value == \"Hedwig\"");
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp64_);
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp61_);
#line 68 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp59_);
#line 70 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp65_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 70 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp66_ = _tmp65_;
#line 70 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp67_ = _tmp66_;
#line 70 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_map_unset (_tmp67_, "alley", NULL);
#line 70 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp67_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp68_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp69_ = _tmp68_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp70_ = _tmp69_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp71_ = gee_map_get (_tmp70_, "alley");
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp72_ = (GXmlNode*) _tmp71_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp72_ == NULL, "elem.attrs.get (\"alley\") == null");
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp72_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 72 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp73_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 72 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp74_ = _tmp73_;
#line 72 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp75_ = _tmp74_;
#line 72 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp76_ = gee_map_get_size (_tmp75_);
#line 72 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp77_ = _tmp76_;
#line 72 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp77_ == 2, "elem.attrs.size == 2");
#line 72 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp75_);
#line 73 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gxml_element_remove_attr ((GXmlElement*) elem, "owl");
#line 74 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp78_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 74 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp79_ = _tmp78_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp80_ = _tmp79_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp81_ = gee_map_get_size (_tmp80_);
#line 74 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp82_ = _tmp81_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp82_ == 1, "elem.attrs.size == 1");
#line 74 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp80_);
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (attr);
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (elem);
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp5_);
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (doc);
#line 778 "GElementTest.c"
	}
	goto __finally167;
	__catch167_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp83_ = NULL;
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		e = _inner_error_;
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_inner_error_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp83_ = e->message;
#line 76 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp83_);
#line 77 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_assert_not_reached ();
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_error_free0 (e);
#line 797 "GElementTest.c"
	}
	__finally167:
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_clear_error (&_inner_error_);
#line 48 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		return;
#line 808 "GElementTest.c"
	}
}


static void ___lambda181__gtest_func (void) {
#line 47 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	__lambda181_ ();
#line 816 "GElementTest.c"
}


static void __lambda182_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* elem = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* t = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		GeeBidirList* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GXmlNode* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlNode* elem2 = NULL;
		GXmlGDocument* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		GXmlNode* t2 = NULL;
		GXmlGDocument* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		GeeBidirList* _tmp24_ = NULL;
		GeeBidirList* _tmp25_ = NULL;
		GeeBidirList* _tmp26_ = NULL;
		GXmlNode* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		GXmlNode* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
#line 82 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 82 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		doc = _tmp0_;
#line 82 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 869 "GElementTest.c"
			goto __catch168_g_error;
		}
#line 83 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = doc;
#line 83 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp2_ = gxml_document_create_element ((GXmlDocument*) _tmp1_, "country", &_inner_error_);
#line 83 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		elem = _tmp2_;
#line 83 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 882 "GElementTest.c"
			goto __catch168_g_error;
		}
#line 84 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp3_ = doc;
#line 84 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp4_ = gxml_document_create_text ((GXmlDocument*) _tmp3_, "New Zealand");
#line 84 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		t = _tmp4_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = t;
#line 85 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp5_ != NULL, "t != null");
#line 86 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp6_ = elem;
#line 86 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp7_ = gxml_node_get_children_nodes (_tmp6_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp9_ = _tmp8_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = t;
#line 86 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp11_ = elem;
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp12_ = gxml_node_to_string (_tmp11_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = _tmp12_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp14_ = g_strconcat ("Elem1:", _tmp13_, NULL);
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp15_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp15_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp13_);
#line 88 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp16_ = elem;
#line 88 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp17_ = gxml_node_to_string (_tmp16_);
#line 88 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 88 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "<country>New Zealand</country>") == 0, "elem.to_string () == \"<country>New Zealand</country>\"");
#line 88 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp18_);
#line 89 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp19_ = doc;
#line 89 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp20_ = gxml_document_create_element ((GXmlDocument*) _tmp19_, "messy", &_inner_error_);
#line 89 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		elem2 = _tmp20_;
#line 89 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 89 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (t);
#line 89 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (elem);
#line 89 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 949 "GElementTest.c"
			goto __catch168_g_error;
		}
#line 90 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp21_ = doc;
#line 90 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp22_ = gxml_document_create_text ((GXmlDocument*) _tmp21_, "&lt;<>&gt;");
#line 90 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		t2 = _tmp22_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp23_ = elem2;
#line 91 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp24_ = gxml_node_get_children_nodes (_tmp23_);
#line 91 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp25_ = _tmp24_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp26_, t2);
#line 91 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp27_ = elem2;
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp28_ = gxml_node_to_string (_tmp27_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp30_ = g_strconcat ("Elem2:", _tmp29_, NULL);
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp31_ = _tmp30_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp31_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp31_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp29_);
#line 93 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp32_ = elem2;
#line 93 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp33_ = gxml_node_to_string (_tmp32_);
#line 93 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp34_ = _tmp33_;
#line 93 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "<messy>&amp;lt;&lt;&gt;&amp;gt;</messy>") == 0, "elem2.to_string () == \"<messy>&amp;lt;&lt;&gt;&amp;gt;</messy>\"");
#line 93 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp34_);
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (t2);
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (elem2);
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (t);
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (elem);
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (doc);
#line 1006 "GElementTest.c"
	}
	goto __finally168;
	__catch168_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp35_ = NULL;
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		e = _inner_error_;
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_inner_error_ = NULL;
#line 95 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp35_ = e->message;
#line 95 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp35_);
#line 96 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_assert_not_reached ();
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_error_free0 (e);
#line 1025 "GElementTest.c"
	}
	__finally168:
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_clear_error (&_inner_error_);
#line 81 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		return;
#line 1036 "GElementTest.c"
	}
}


static void ___lambda182__gtest_func (void) {
#line 80 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	__lambda182_ ();
#line 1044 "GElementTest.c"
}


static void __lambda183_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlGElement* root = NULL;
		GXmlNode* _tmp3_ = NULL;
		GeeBidirList* _tmp4_ = NULL;
		GeeBidirList* _tmp5_ = NULL;
		GeeBidirList* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* s = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar** _tmp11_ = NULL;
		gchar** _tmp12_ = NULL;
		gchar** _tmp13_ = NULL;
		gint _tmp13__length1 = 0;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 101 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 101 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		doc = _tmp0_;
#line 102 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp2_ = gxml_document_create_element ((GXmlDocument*) doc, "root", &_inner_error_);
#line 102 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = _tmp2_;
#line 102 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 102 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 1084 "GElementTest.c"
			goto __catch169_g_error;
		}
#line 102 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp3_ = _tmp1_;
#line 102 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 103 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp4_ = gxml_gnode_get_children_nodes ((GXmlGNode*) doc);
#line 103 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp6_ = _tmp5_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp6_, (GXmlNode*) G_TYPE_CHECK_INSTANCE_CAST (root, GXML_TYPE_GNODE, GXmlGNode));
#line 103 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 104 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gxml_element_set_content ((GXmlElement*) root, "TEXT1");
#line 105 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) root);
#line 105 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "<root>TEXT1</root>") == 0, "root.to_string () == \"<root>TEXT1</root>\"");
#line 105 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp8_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp9_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = _tmp9_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp12_ = _tmp11_ = g_strsplit (_tmp10_, "\n", 0);
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = _tmp12_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13__length1 = _vala_array_length (_tmp11_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp14_ = _tmp13_[1];
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp15_ = g_strdup (_tmp14_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp10_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		s = _tmp16_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root>TEXT1</root>") == 0, "s == \"<root>TEXT1</root>\"");
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (s);
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (root);
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (doc);
#line 1145 "GElementTest.c"
	}
	goto __finally169;
	__catch169_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp17_ = NULL;
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		e = _inner_error_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_inner_error_ = NULL;
#line 109 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp17_ = e->message;
#line 109 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp17_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_assert_not_reached ();
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_error_free0 (e);
#line 1164 "GElementTest.c"
	}
	__finally169:
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_clear_error (&_inner_error_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		return;
#line 1175 "GElementTest.c"
	}
}


static void ___lambda183__gtest_func (void) {
#line 99 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	__lambda183_ ();
#line 1183 "GElementTest.c"
}


static void __lambda184_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlGElement* root = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlGDocument* _tmp5_ = NULL;
		GeeBidirList* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		GXmlGElement* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GXmlGDocument* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlGElement* n = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlGElement* _tmp14_ = NULL;
		GeeBidirList* _tmp15_ = NULL;
		GeeBidirList* _tmp16_ = NULL;
		GeeBidirList* _tmp17_ = NULL;
		GXmlNode* t = NULL;
		GXmlGDocument* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlGElement* _tmp20_ = NULL;
		GeeBidirList* _tmp21_ = NULL;
		GeeBidirList* _tmp22_ = NULL;
		GeeBidirList* _tmp23_ = NULL;
		gchar* s = NULL;
		GXmlGDocument* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar** _tmp27_ = NULL;
		gchar** _tmp28_ = NULL;
		gchar** _tmp29_ = NULL;
		gint _tmp29__length1 = 0;
		const gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		GXmlGElement* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
#line 115 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 115 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		doc = _tmp0_;
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp2_ = doc;
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp3_ = gxml_document_create_element ((GXmlDocument*) _tmp2_, "root", &_inner_error_);
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = _tmp3_;
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 1248 "GElementTest.c"
			goto __catch170_g_error;
		}
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp4_ = _tmp1_;
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = NULL;
#line 116 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 117 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = doc;
#line 117 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp6_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp5_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 117 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 117 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp9_ = root;
#line 117 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlNode*) _tmp9_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp11_ = doc;
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp12_ = gxml_document_create_element ((GXmlDocument*) _tmp11_, "child", &_inner_error_);
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = _tmp12_;
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (root);
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 1285 "GElementTest.c"
			goto __catch170_g_error;
		}
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = _tmp10_;
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = NULL;
#line 118 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		n = G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 119 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp14_ = root;
#line 119 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp15_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp14_);
#line 119 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 119 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 119 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlNode*) n);
#line 119 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 120 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp18_ = doc;
#line 120 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp19_ = gxml_document_create_text ((GXmlDocument*) _tmp18_, "TEXT1");
#line 120 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		t = _tmp19_;
#line 121 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp20_ = root;
#line 121 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp21_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp20_);
#line 121 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp22_ = _tmp21_;
#line 121 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 121 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp23_, t);
#line 121 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp24_ = doc;
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp25_ = gxml_gnode_to_string ((GXmlGNode*) _tmp24_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp28_ = _tmp27_ = g_strsplit (_tmp26_, "\n", 0);
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29__length1 = _vala_array_length (_tmp27_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp30_ = _tmp29_[1];
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp31_ = g_strdup (_tmp30_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp32_ = _tmp31_;
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = (_vala_array_free (_tmp29_, _tmp29__length1, (GDestroyNotify) g_free), NULL);
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp26_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		s = _tmp32_;
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp33_ = root;
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp34_ = gxml_gnode_to_string ((GXmlGNode*) _tmp33_);
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp35_ = _tmp34_;
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp36_ = g_strconcat ("root=", _tmp35_, NULL);
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp37_ = _tmp36_;
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp37_);
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp37_);
#line 123 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp35_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (s);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (t);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (n);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (root);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (doc);
#line 1380 "GElementTest.c"
	}
	goto __finally170;
	__catch170_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp38_ = NULL;
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		e = _inner_error_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_inner_error_ = NULL;
#line 126 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp38_ = e->message;
#line 126 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp38_);
#line 127 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_assert_not_reached ();
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_error_free0 (e);
#line 1399 "GElementTest.c"
	}
	__finally170:
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_clear_error (&_inner_error_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		return;
#line 1410 "GElementTest.c"
	}
}


static void ___lambda184__gtest_func (void) {
#line 113 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	__lambda184_ ();
#line 1418 "GElementTest.c"
}


static void __lambda185_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlGElement* root = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlGDocument* _tmp5_ = NULL;
		GeeBidirList* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		GXmlGElement* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GXmlGDocument* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlGElement* n = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlGElement* _tmp14_ = NULL;
		GeeBidirList* _tmp15_ = NULL;
		GeeBidirList* _tmp16_ = NULL;
		GeeBidirList* _tmp17_ = NULL;
		GXmlText* t = NULL;
		GXmlGDocument* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlGElement* _tmp20_ = NULL;
		GeeBidirList* _tmp21_ = NULL;
		GeeBidirList* _tmp22_ = NULL;
		GeeBidirList* _tmp23_ = NULL;
		gchar* s = NULL;
		GXmlGDocument* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar** _tmp27_ = NULL;
		gchar** _tmp28_ = NULL;
		gchar** _tmp29_ = NULL;
		gint _tmp29__length1 = 0;
		const gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
#line 132 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 132 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		doc = _tmp0_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp2_ = doc;
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp3_ = gxml_document_create_element ((GXmlDocument*) _tmp2_, "root", &_inner_error_);
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = _tmp3_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 1478 "GElementTest.c"
			goto __catch171_g_error;
		}
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp4_ = _tmp1_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = NULL;
#line 133 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 134 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = doc;
#line 134 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp6_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp5_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp9_ = root;
#line 134 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlNode*) _tmp9_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp11_ = doc;
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp12_ = gxml_document_create_element ((GXmlDocument*) _tmp11_, "child", &_inner_error_);
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = _tmp12_;
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (root);
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
			_g_object_unref0 (doc);
#line 1515 "GElementTest.c"
			goto __catch171_g_error;
		}
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = _tmp10_;
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = NULL;
#line 135 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		n = G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 136 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp14_ = root;
#line 136 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp15_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp14_);
#line 136 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlNode*) n);
#line 136 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 137 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp18_ = doc;
#line 137 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp19_ = gxml_document_create_text ((GXmlDocument*) _tmp18_, "TEXT1");
#line 137 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		t = G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GXML_TYPE_TEXT, GXmlText);
#line 138 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp20_ = root;
#line 138 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp21_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp20_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp22_ = _tmp21_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp23_, (GXmlNode*) t);
#line 138 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp24_ = doc;
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp25_ = gxml_gnode_to_string ((GXmlGNode*) _tmp24_);
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp28_ = _tmp27_ = g_strsplit (_tmp26_, "\n", 0);
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29__length1 = _vala_array_length (_tmp27_);
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp30_ = _tmp29_[1];
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp31_ = g_strdup (_tmp30_);
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp32_ = _tmp31_;
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = (_vala_array_free (_tmp29_, _tmp29__length1, (GDestroyNotify) g_free), NULL);
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp26_);
#line 139 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		s = _tmp32_;
#line 140 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (s);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (t);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (n);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (root);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (doc);
#line 1594 "GElementTest.c"
	}
	goto __finally171;
	__catch171_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp33_ = NULL;
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		e = _inner_error_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_inner_error_ = NULL;
#line 142 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp33_ = e->message;
#line 142 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp33_);
#line 143 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_assert_not_reached ();
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_error_free0 (e);
#line 1613 "GElementTest.c"
	}
	__finally171:
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_clear_error (&_inner_error_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		return;
#line 1624 "GElementTest.c"
	}
}


static void ___lambda185__gtest_func (void) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	__lambda185_ ();
#line 1632 "GElementTest.c"
}


static void __lambda186_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlNode* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		GXmlNode* _tmp18_ = NULL;
		GeeBidirList* _tmp19_ = NULL;
		GeeBidirList* _tmp20_ = NULL;
		GeeBidirList* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		GXmlNode* _tmp24_ = NULL;
		GXmlNode* _tmp25_ = NULL;
		GXmlNode* _tmp26_ = NULL;
		GeeBidirList* _tmp27_ = NULL;
		GeeBidirList* _tmp28_ = NULL;
		GeeBidirList* _tmp29_ = NULL;
		gpointer _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GXmlNode* _tmp32_ = NULL;
		GXmlNode* _tmp33_ = NULL;
		GXmlNode* _tmp34_ = NULL;
		GXmlNode* _tmp35_ = NULL;
		GXmlNode* _tmp36_ = NULL;
		GXmlNode* _tmp37_ = NULL;
		GeeBidirList* _tmp38_ = NULL;
		GeeBidirList* _tmp39_ = NULL;
		GeeBidirList* _tmp40_ = NULL;
		gpointer _tmp41_ = NULL;
		GXmlNode* _tmp42_ = NULL;
		GXmlNode* _tmp43_ = NULL;
		GXmlNode* _tmp44_ = NULL;
		GXmlNode* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
#line 148 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root><child/></root>", 0, &_inner_error_);
#line 148 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		doc = _tmp0_;
#line 148 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1695 "GElementTest.c"
			goto __catch172_g_error;
		}
#line 149 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 149 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp2_ = _tmp1_;
#line 149 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp3_ = _tmp2_;
#line 149 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 149 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp6_ = _tmp5_;
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp7_ = gxml_node_get_parent (_tmp6_);
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp9_ = _tmp8_;
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_NODE), "doc.root.parent is GXml.Node");
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 150 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp11_ = _tmp10_;
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp12_ = _tmp11_;
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp13_ = gxml_node_get_parent (_tmp12_);
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp14_ = _tmp13_;
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOCUMENT), "doc.root.parent is GXml.Document");
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 151 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp16_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp19_ = gxml_node_get_children_nodes (_tmp18_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp20_ = _tmp19_;
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp23_ = (GXmlNode*) _tmp22_;
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.root.children_nodes[0] != null");
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 152 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp24_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp25_ = _tmp24_;
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp27_ = gxml_node_get_children_nodes (_tmp26_);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp31_ = (GXmlNode*) _tmp30_;
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp32_ = gxml_node_get_parent (_tmp31_);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp33_ = _tmp32_;
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp34_ = _tmp33_;
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.root.children_nodes[0].parent != null");
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 153 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp35_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp36_ = _tmp35_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp37_ = _tmp36_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp38_ = gxml_node_get_children_nodes (_tmp37_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp39_ = _tmp38_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp40_ = _tmp39_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp42_ = (GXmlNode*) _tmp41_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp43_ = gxml_node_get_parent (_tmp42_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp44_ = _tmp43_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp45_ = _tmp44_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp46_ = gxml_node_get_name (_tmp45_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp47_ = _tmp46_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp48_ = _tmp47_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.root.children_nodes[0].parent.name == \"root\"");
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_free0 (_tmp48_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_object_unref0 (doc);
#line 1842 "GElementTest.c"
	}
	goto __finally172;
	__catch172_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_ = NULL;
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		e = _inner_error_;
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_inner_error_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_tmp49_ = e->message;
#line 156 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_test_message ("%s", _tmp49_);
#line 157 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_assert_not_reached ();
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		_g_error_free0 (e);
#line 1861 "GElementTest.c"
	}
	__finally172:
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		g_clear_error (&_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
		return;
#line 1872 "GElementTest.c"
	}
}


static void ___lambda186__gtest_func (void) {
#line 146 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	__lambda186_ ();
#line 1880 "GElementTest.c"
}


void gelement_test_add_tests (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	g_test_add_func ("/gxml/gelement/namespace_uri", ___lambda180__gtest_func);
#line 47 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	g_test_add_func ("/gxml/gelement/attributes", ___lambda181__gtest_func);
#line 80 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	g_test_add_func ("/gxml/gelement/to_string", ___lambda182__gtest_func);
#line 99 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	g_test_add_func ("/gxml/gelement/content/set", ___lambda183__gtest_func);
#line 113 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	g_test_add_func ("/gxml/gelement/content/add_aside_child_nodes", ___lambda184__gtest_func);
#line 130 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	g_test_add_func ("/gxml/gelement/content/keep_child_nodes", ___lambda185__gtest_func);
#line 146 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	g_test_add_func ("/gxml/gelement/parent", ___lambda186__gtest_func);
#line 1899 "GElementTest.c"
}


GElementTest* gelement_test_construct (GType object_type) {
	GElementTest* self = NULL;
#line 25 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	self = (GElementTest*) gxml_test_construct (object_type);
#line 25 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	return self;
#line 1909 "GElementTest.c"
}


GElementTest* gelement_test_new (void) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	return gelement_test_construct (TYPE_GELEMENT_TEST);
#line 1916 "GElementTest.c"
}


static void gelement_test_class_init (GElementTestClass * klass) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GElementTest.vala"
	gelement_test_parent_class = g_type_class_peek_parent (klass);
#line 1923 "GElementTest.c"
}


static void gelement_test_instance_init (GElementTest * self) {
}


GType gelement_test_get_type (void) {
	static volatile gsize gelement_test_type_id__volatile = 0;
	if (g_once_init_enter (&gelement_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GElementTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gelement_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GElementTest), 0, (GInstanceInitFunc) gelement_test_instance_init, NULL };
		GType gelement_test_type_id;
		gelement_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GElementTest", &g_define_type_info, 0);
		g_once_init_leave (&gelement_test_type_id__volatile, gelement_test_type_id);
	}
	return gelement_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



